@@ -53,7 +53,7 @@ def judge_command():
             return
 
         variables = m.variables()
-        print("Found variables: {}".format(variables))
+        print(f"Found variables: {variables}")
         for expect_token, expect_value in expect.items():
             all_variables = variables.getall(expect_token)
             if len(all_variables) > 1:
@@ -105,7 +105,7 @@ def cli():
 
     child = pexpect.spawn(f"iredis -n 15 --iredisrc {f.name}", timeout=TIMEOUT, env=env)
     child.logfile_read = open("cli_test.log", "ab")
-    child.expect(["https://iredis.io/issues", "127.0.0.1"])
+    child.expect(["https://github.com/laixintao/iredis/issues", "127.0.0.1"])
     yield child
     child.close()
 
@@ -129,7 +129,7 @@ def raw_cli():
         f"iredis --raw -n 15 --iredisrc {TEST_IREDISRC}", timeout=TIMEOUT
     )
     child.logfile_read = open("cli_test.log", "ab")
-    child.expect(["https://iredis.io/issues", "127.0.0.1"])
+    child.expect(["https://github.com/laixintao/iredis/issues", "127.0.0.1"])
     yield child
     child.close()
 
